#!/usr/bin/env node

const chalk = require('chalk');
const clear = require('clear');
const figlet = require('figlet');
const CLI = require('clui');
const Spinner = CLI.Spinner;
const player = require('play-sound')((opts = {}));

// $ mplayer foo.mp3
player.play('./assets/open.mp3', function (err) {
  if (err) throw err;
});

const inquirer = require('./lib/inquirer');
const { blueBright } = require('chalk');

clear();
console.log(
  chalk.magenta(`                              
  MMMMMMMMMMMWXOdl:;,,,,;:ldkKNWMMMMMMMMMM
  MMMMMMMMMNOl,..............'cxKWMMMMMMMM
  MMMMMMMNO:....................:xXWMMMMMM
  MMMMMMKl.......................,oKWMMMMM
  MMMMMKc.........................,dXMMMMM
  MMMMNd...........................;OWMMMM
  MMMMX:...........................'dNMMMM
  MMMMK:...........................'dNMMMM
  MMMMNo...........................,kWMMMM
  MMMMM0:..........................cKWMMMM
  MMMMMW0:.......................'l0WMMMMM
  MMMMMMWKl..................',:okXWMMMMMM
  MMMMMMMWNOc,........',;cclodk0XWWMMMMMMM
  MMMMMMMMMMN0xoc:cldkO0KKKXXNNWMMMMMMMMMM
`)
);
console.log(
  chalk.magenta(figlet.textSync('maslo', { horizontalLayout: 'full' }))
);
console.log(
  chalk.magenta(`   Hi from maslo! Let’s get started.
   I'll guide you to create your companion.
`)
);

(async () => {
  const serverConfig = await inquirer.askServerQuestions();
  const status = new Spinner('Creating a bunch of stuff...');
  console.log(`
  Great, here’s what I’ll do to create your companion:
    🤖 Configure a companion named ${blueBright(serverConfig.appName)}
    🛠  Create a new folder called ${blueBright(serverConfig.folderName)}
    📚 Install and configure the hosting for ${blueBright(
      serverConfig.cloudProvider
    )}
    🎨 The primary color scheme will be (color)
    🔌 Install OpenAI capabilities
    `);
  const confirmation = await inquirer.confirm();
  if (confirmation.response) {
    status.start();
    setTimeout(() => {
      player.play('./assets/joy.mp3', function (err) {
        if (err) throw err;
      });
      status.stop();
      console.log(`
    ${chalk.magentaBright('Your companion was created succesfully! 🤖')}
      `);
    }, 3000);
  }
})();
